linux-next: manual merge of the bpf-next tree with the bpf tree

From: Stephen Rothwell
Date: Mon Dec 03 2018 - 20:05:35 EST


Hi all,

Today's linux-next merge of the bpf-next tree got conflicts in:

include/uapi/linux/bpf.h

between commit:

d74286d2c25a ("bpf: Improve socket lookup reuseport documentation")

from the bpf tree and commit:

90b1023f68c7 ("bpf: fix documentation for eBPF helpers")

from the bpf-next tree.

I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.

--
Cheers,
Stephen Rothwell

diff --cc include/uapi/linux/bpf.h
index ec8b40ff386e,572eb2d42768..000000000000
--- a/include/uapi/linux/bpf.h
+++ b/include/uapi/linux/bpf.h
@@@ -2209,11 -2210,11 +2212,11 @@@ union bpf_attr
* This helper is available only if the kernel was compiled with
* **CONFIG_NET** configuration option.
* Return
- * Pointer to *struct bpf_sock*, or NULL in case of failure.
- * For sockets with reuseport option, the *struct bpf_sock*
- * result is from reuse->socks[] using the hash of the tuple.
+ * A pointer to *struct bpf_sock*, or **NULL** in case of failure.
- * For sockets with reuseport option, **struct bpf_sock**
++ * For sockets with reuseport option, the **struct bpf_sock**
+ * return is from **reuse->socks**\ [] using hash of the packet.
*
- * struct bpf_sock *bpf_sk_lookup_udp(void *ctx, struct bpf_sock_tuple *tuple, u32 tuple_size, u32 netns, u64 flags)
+ * struct bpf_sock *bpf_sk_lookup_udp(void *ctx, struct bpf_sock_tuple *tuple, u32 tuple_size, u64 netns, u64 flags)
* Description
* Look for UDP socket matching *tuple*, optionally in a child
* network namespace *netns*. The return value must be checked,
@@@ -2245,14 -2244,15 +2248,16 @@@
* This helper is available only if the kernel was compiled with
* **CONFIG_NET** configuration option.
* Return
- * Pointer to *struct bpf_sock*, or NULL in case of failure.
- * For sockets with reuseport option, the *struct bpf_sock*
- * result is from reuse->socks[] using the hash of the tuple.
+ * A pointer to **struct bpf_sock**, or **NULL** in case of
- * failure. For sockets with reuseport option, **struct bpf_sock**
- * return is from **reuse->socks**\ [] using hash of the packet.
++ * failure. For sockets with reuseport option, the
++ * **struct bpf_sock** return is from **reuse->socks**\ []
++ * using hash of the packet.
*
- * int bpf_sk_release(struct bpf_sock *sk)
+ * int bpf_sk_release(struct bpf_sock *sock)
* Description
- * Release the reference held by *sock*. *sock* must be a non-NULL
- * pointer that was returned from bpf_sk_lookup_xxx\ ().
+ * Release the reference held by *sock*. *sock* must be a
+ * non-**NULL** pointer that was returned from
+ * **bpf_sk_lookup_xxx**\ ().
* Return
* 0 on success, or a negative error in case of failure.
*
@@@ -2494,8 -2495,9 +2509,9 @@@ struct __sk_buff
/* ... here. */

__u32 data_meta;
- struct bpf_flow_keys *flow_keys;
+ __bpf_md_ptr(struct bpf_flow_keys *, flow_keys);
__u64 tstamp;
+ __u32 wire_len;
};

struct bpf_tunnel_key {

Attachment: pgpjWuHA1BW3G.pgp
Description: OpenPGP digital signature